#Suluoya
This is a package written by Suluoya just for fun!

eg.
import Suluoya as sly

#Search for questions from mooc
answer=sly.search_question('Here with your question')
print(answer)

#Download music
sly.download_music()

